# johnsnowlabs
The John Snow Labs Library gives you access to all of John Snow Labs Enterprise And Open Source products in an easy and simple manner. Access 10000+ state-of-the-art NLP and OCR models for '
'Finance, Legal and Medical domains. Easily scalable to Spark Cluster.
See https://www.johnsnowlabs.com/  and [the docs](https://nlu.johnsnowlabs.com/docs/en/install) for more detials